@@ -1,4 +1,5 @@
 package Net::Stripe;
+$Net::Stripe::VERSION = '0.17';
 use Moose;
 use Kavorka;
 use LWP::UserAgent;
@@ -21,8 +22,6 @@ use Net::Stripe::BalanceTransaction;
 use Net::Stripe::List;
 use Net::Stripe::LineItem;
 
-our $VERSION = '0.15';
-
 # ABSTRACT: API client for Stripe.com
 
 
@@ -223,7 +222,10 @@ Cards: {
         if (ref($card) eq 'HASH') {
             $card = Net::Stripe::Card->new($card);
         }
-        return $self->_post("customers/$customer/cards/" . $card->id, $card);
+        if (defined($card->id)) {
+            return $self->_post("customers/$customer/cards/" . $card->id, $card);
+        }
+        return $self->_post("customers/$customer/cards", $card);
     }
 
     method delete_card(Net::Stripe::Customer|Str :$customer, Net::Stripe::Card|Str :$card) {
@@ -442,6 +444,10 @@ Invoices: {
         return $self->_get("invoices/$invoice_id");
     }
 
+    method pay_invoice(Str :$invoice_id) {
+        return $self->_post("invoices/$invoice_id/pay");
+    }
+
     method get_invoices(Net::Stripe::Customer|Str :$customer?,
                         Int|HashRef :$date?,
                         Str :$ending_before?, 
@@ -688,7 +694,7 @@ method _build_api_base { 'https://api.stripe.com/v1' }
 
 method _build_ua {
     my $ua = LWP::UserAgent->new(keep_alive => 4);
-    $ua->agent("Net::Stripe/$VERSION");
+    $ua->agent("Net::Stripe/" . $Net::Stripe::VERSION);
     return $ua;
 }
 
@@ -706,7 +712,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -1421,6 +1427,18 @@ Returns a L<Net::Stripe::Invoice>
 
   $stripe->get_invoice(invoice_id => 'testinvoice');
 
+=head2 pay_invoice
+
+=over
+
+=item * invoice_id - Str
+
+=back
+
+Returns a L<Net::Stripe::Invoice>
+
+  $stripe->pay_invoice(invoice_id => 'testinvoice');
+
 =head2 get_invoices
 
 Returns a list of invoices
